@@ -1,6 +1,8 @@
 from inspect import iscoroutinefunction
 from typing import (
+    Any,
     AsyncIterator,
+    AsyncGenerator,
     Iterable,
     AsyncIterable,
     Union,
@@ -8,7 +10,9 @@ from typing import (
     Optional,
     Awaitable,
     Callable,
+    Type,
 )
+from types import TracebackType
 
 from ._typing import T, AnyIterable
 
@@ -18,10 +22,10 @@ class Sentinel:
 
     __slots__ = ("name",)
 
-    def __init__(self, name):
+    def __init__(self, name: str):
         self.name = name
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return self.name
 
 
@@ -67,7 +71,12 @@ class ScopedIter(Generic[T]):
         self._iterable = None
         return self._iterator
 
-    async def __aexit__(self, exc_type, exc_val, exc_tb) -> bool:
+    async def __aexit__(
+        self,
+        exc_type: Optional[Type[BaseException]],
+        exc_val: Optional[BaseException],
+        exc_tb: Optional[TracebackType],
+    ) -> bool:
         try:
             aclose = self._iterator.aclose()  # type: ignore
         except AttributeError:
@@ -77,7 +86,7 @@ class ScopedIter(Generic[T]):
         return False
 
 
-async def borrow(iterator: AsyncIterator):
+async def borrow(iterator: AsyncIterator[T]) -> AsyncGenerator[T, None]:
     """Borrow an async iterator for iteration, preventing it from being closed"""
     async for item in iterator:
         yield item
@@ -102,7 +111,7 @@ class Awaitify(Generic[T]):
         self.__wrapped__ = function
         self._async_call: Optional[Callable[..., Awaitable[T]]] = None
 
-    def __call__(self, *args, **kwargs) -> Awaitable[T]:
+    def __call__(self, *args: Any, **kwargs: Any) -> Awaitable[T]:
         async_call = self._async_call
         if async_call is None:
             value = self.__wrapped__(*args, **kwargs)
@@ -121,7 +130,7 @@ async def await_value(value: T) -> T:
 
 
 def force_async(call: Callable[..., T]) -> Callable[..., Awaitable[T]]:
-    async def async_wrapped(*args, **kwargs):
+    async def async_wrapped(*args: Any, **kwargs: Any) -> T:
         return call(*args, **kwargs)
 
     return async_wrapped
