@@ -1,4 +1,4 @@
-from typing import TypeVar, Any, Optional
+from typing import TypeVar, Any, Optional, Callable
 
 from ._typing import Protocol
 
@@ -16,7 +16,9 @@ class Definition(Protocol):
 D = TypeVar("D", bound=Definition)
 
 
-def public_module(module_name: str, qual_name: Optional[str] = None):
+def public_module(
+    module_name: str, qual_name: Optional[str] = None
+) -> Callable[[D], D]:
     """Set the module name of a function or class"""
 
     def decorator(thing: D) -> D:
